==> moodle_1.3.1.orig.tar.gz: moodle/lang/en/editor.php <==
<?PHP // $Id: editor.php,v 1.9 2004/05/15 03:21:41 moodler Exp $ 
      // editor.php - created with Moodle 1.2 (2004032000)


$string['about'] = 'About this editor';
$string['absbottom'] = 'Absbottom';
$string['absmiddle'] = 'Absmiddle';
$string['address'] = 'Address';
$string['alignment'] = 'Alignment';
$string['alternatetext'] = 'Alternate text';
$string['baseline'] = 'Baseline';
$string['bold'] = 'Bold';
$string['borderthickness'] = 'Border thickness';
$string['bottom'] = 'Bottom';
$string['browse'] = 'Browse';
$string['cancel'] = 'Cancel';
$string['cellpadding'] = 'Cellpadding';
$string['cellspacing'] = 'Cellspacing';
$string['choosechar'] = 'Choose Character';
$string['chooseicon'] = 'Choose an icon to insert';
$string['close'] = 'Close';
$string['cols'] = 'Cols';
$string['copy'] = 'Copy selection';
$string['createfolder'] = 'Create folder';
$string['createlink'] = 'Insert Web Link';
$string['cut'] = 'Cut selection';
$string['delete'] = 'Delete';
$string['filebrowser'] = 'File Browser';
$string['forecolor'] = 'Font Color';
$string['fullscreen'] = 'Fullscreen editor';
$string['heading'] = 'Heading';
$string['height'] = 'Height';
$string['hilitecolor'] = 'Background Color';
$string['horizontal'] = 'Horizontal';
$string['horizontalrule'] = 'Horizontal Rule';
$string['htmlmode'] = 'Toggle HTML Source';
$string['imageurl'] = 'Image URL';
$string['indent'] = 'Increase Indent';
$string['insertchar'] = 'Insert Special Character';
$string['insertimage'] = 'Insert Image';
$string['insertlink'] = 'Insert Link';
$string['insertsmile'] = 'Insert Smiley';
$string['inserttable'] = 'Insert Table';
$string['italic'] = 'Italic';
$string['justifycenter'] = 'Justify Center';
$string['justifyfull'] = 'Justify Full';
$string['justifyleft'] = 'Justify Left';
$string['justifyright'] = 'Justify Right';
$string['layout'] = 'Layout';
$string['left'] = 'Left';
$string['lefttoright'] = 'Direction from left to right';
$string['linkproperties'] = 'Link properties';
$string['linktarget'] = 'Target';
$string['linktargetblank'] = 'New window';
$string['linktargetnone'] = 'None';
$string['linktargetother'] = 'Other (out of order)';
$string['linktargetself'] = 'Same frame';
$string['linktargettop'] = 'Same window';
$string['linktitle'] = 'Title';
$string['linkurl'] = 'URL';
$string['middle'] = 'Middle';
$string['minimize'] = 'Minimize editor';
$string['move'] = 'Move';
$string['normal'] = 'Normal';
$string['notimage'] = 'Selected file is not an image. Please select an image!';
$string['notset'] = 'Not Set';
$string['ok'] = 'OK';
$string['orderedlist'] = 'Ordered List';
$string['outdent'] = 'Decrease Indent';
$string['paste'] = 'Paste from clipboard';
$string['path'] = 'Path';
$string['percent'] = 'Percent';
$string['pixels'] = 'Pixels';
$string['popupeditor'] = 'Enlarge Editor';
$string['preformatted'] = 'Preformatted';
$string['preview'] = 'Preview';
$string['properties'] = 'Properties';
$string['redo'] = 'Redo your last action';
$string['rename'] = 'Rename';
$string['removelink'] = 'Remove link';
$string['right'] = 'Right';
$string['righttoleft'] = 'Direction from right to left';
$string['rows'] = 'Rows';
$string['selectcolor'] = 'Select color'; 
$string['selection'] = 'Selection';
$string['showhelp'] = 'Help using editor';
$string['size'] = 'Size';
$string['spacing'] = 'Spacing';
$string['strikethrough'] = 'Strikethrough';
$string['subscript'] = 'Subscript';
$string['superscript'] = 'Superscript';
$string['textindicator'] = 'Current style';
$string['textmode'] = 'You are in TEXT MODE.  Use the [<>] button to go back to WYSIWYG MODE.';
$string['texttop'] = 'Texttop';
$string['top'] = 'Top';
$string['type'] = 'Type';
$string['underline'] = 'Underline';
$string['undo'] = 'Undo your last action';
$string['unorderedlist'] = 'Bulleted List';
$string['upload'] = 'Upload';
$string['vertical'] = 'Vertical';
$string['width'] = 'Width';
$string['wordclean'] = 'Clean Word HTML';
$string['zip'] = 'Zip';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/en/editor.php <==
<?php // $Id$
      // editor.php - created with Moodle 1.2 (2004032000)


$string['about'] = 'About this editor';
$string['absbottom'] = 'Absbottom';
$string['middle'] = 'middle';
$string['address'] = 'Address';
$string['alignment'] = 'Alignment';
$string['alternatetext'] = 'Alternate text';
$string['anchorname'] = 'Anchor name';
$string['anchorhelp'] = 'This only creates an anchor.  You still need to create a link manually.';
$string['anchors'] = 'Anchors';
$string['baseline'] = 'Baseline';
$string['bold'] = 'Bold';
$string['borderthickness'] = 'Border thickness';
$string['bottom'] = 'Bottom';
$string['browse'] = 'Browse';
$string['cancel'] = 'Cancel';
$string['cellpadding'] = 'Cellpadding';
$string['cellspacing'] = 'Cellspacing';
$string['choosechar'] = 'Choose Character';
$string['chooseicon'] = 'Choose an icon to insert';
$string['close'] = 'Close';
$string['cols'] = 'Cols';
$string['copy'] = 'Copy selection';
$string['createanchor'] = 'Create anchor';
$string['createfolder'] = 'Create folder';
$string['createlink'] = 'Insert Web Link';
$string['cut'] = 'Cut selection';
$string['delete'] = 'Delete';
$string['filebrowser'] = 'File Browser';
$string['forecolor'] = 'Font Color';
$string['fullscreen'] = 'Fullscreen editor';
$string['heading'] = 'Heading';
$string['height'] = 'Height';
$string['hilitecolor'] = 'Background Color';
$string['horizontal'] = 'Horizontal';
$string['horizontalrule'] = 'Horizontal Rule';
$string['htmlmode'] = 'Toggle HTML Source';
$string['imageurl'] = 'Image URL';
$string['indent'] = 'Increase Indent';
$string['insertchar'] = 'Insert Special Character';
$string['insertimage'] = 'Insert Image';
$string['insertlink'] = 'Insert Link';
$string['insertsmile'] = 'Insert Smiley';
$string['inserttable'] = 'Insert Table';
$string['italic'] = 'Italic';
$string['justifycenter'] = 'Justify Center';
$string['justifyfull'] = 'Justify Full';
$string['justifyleft'] = 'Justify Left';
$string['justifyright'] = 'Justify Right';
$string['layout'] = 'Layout';
$string['left'] = 'Left';
$string['lefttoright'] = 'Direction from left to right';
$string['linkproperties'] = 'Link properties';
$string['linktarget'] = 'Target';
$string['linktargetblank'] = 'New window';
$string['linktargetnone'] = 'None';
$string['linktargetother'] = 'Other (out of order)';
$string['linktargetself'] = 'Same frame';
$string['linktargettop'] = 'Same window';
$string['linktitle'] = 'Title';
$string['linkurl'] = 'URL';
$string['middle'] = 'Middle';
$string['minimize'] = 'Minimize editor';
$string['move'] = 'Move';
$string['normal'] = 'Normal';
$string['notimage'] = 'Selected file is not an image. Please select an image!';
$string['notset'] = 'Not Set';
$string['ok'] = 'OK';
$string['orderedlist'] = 'Ordered List';
$string['outdent'] = 'Decrease Indent';
$string['paste'] = 'Paste from clipboard';
$string['path'] = 'Path';
$string['percent'] = 'Percent';
$string['pixels'] = 'Pixels';
$string['popupeditor'] = 'Enlarge Editor';
$string['preformatted'] = 'Preformatted';
$string['preview'] = 'Preview';
$string['properties'] = 'Properties';
$string['redo'] = 'Redo your last action';
$string['rename'] = 'Rename';
$string['removelink'] = 'Remove link';
$string['right'] = 'Right';
$string['righttoleft'] = 'Direction from right to left';
$string['rows'] = 'Rows';
$string['selectcolor'] = 'Select color';
$string['selection'] = 'Selection';
$string['showhelp'] = 'Help using editor';
$string['size'] = 'Size';
$string['spacing'] = 'Spacing';
$string['strikethrough'] = 'Strikethrough';
$string['subscript'] = 'Subscript';
$string['superscript'] = 'Superscript';
$string['textindicator'] = 'Current style';
$string['textmode'] = 'You are in TEXT MODE.  Use the [<>] button to go back to WYSIWYG MODE.';
$string['texttop'] = 'Texttop';
$string['top'] = 'Top';
$string['type'] = 'Type';
$string['underline'] = 'Underline';
$string['undo'] = 'Undo your last action';
$string['unorderedlist'] = 'Bulleted List';
$string['upload'] = 'Upload';
$string['vertical'] = 'Vertical';
$string['width'] = 'Width';
$string['wordclean'] = 'Clean Word HTML';
$string['zip'] = 'Zip';
$string['createanchor'] = 'Create anchor';
$string['anchorname'] = 'Anchorname';
$string['fontname'] = 'Fontname';
$string['fontsize'] = 'Font-size';
$string['formatblock'] = 'Format';
$string['nolink'] = 'Prevent glossary link';
$string['alertnoselectedtext'] = 'You must select text first!';

?>
